@@ -24,8 +24,8 @@ from typing import (
 from di._inspect import is_async_gen_callable, is_gen_callable
 from di._state import ContainerState
 from di.exceptions import IncompatibleDependencyError
-from di.types.dependencies import DependantProtocol, DependencyParameter
-from di.types.executor import Task as ExecutorTask
+from di.types.dependencies import DependantBase, DependencyParameter
+from di.types.executor import AsyncTaskInfo, SyncTaskInfo, TaskInfo
 from di.types.providers import (
     AsyncGeneratorProvider,
     CallableProvider,
@@ -37,9 +37,9 @@ from di.types.providers import (
 
 class ExecutionState(typing.NamedTuple):
     container_state: ContainerState
-    results: Dict[DependantProtocol[Any], Any]
-    dependency_counts: MutableMapping[DependantProtocol[Any], int]
-    dependants: Mapping[DependantProtocol[Any], Iterable[Task[Any]]]
+    results: Dict[DependantBase[Any], Any]
+    dependency_counts: MutableMapping[DependantBase[Any], int]
+    dependants: Mapping[DependantBase[Any], Iterable[Task[Any]]]
 
 
 class Task(Generic[DependencyType]):
@@ -47,7 +47,7 @@ class Task(Generic[DependencyType]):
 
     def __init__(
         self,
-        dependant: DependantProtocol[DependencyType],
+        dependant: DependantBase[DependencyType],
         dependencies: List[DependencyParameter[Task[Any]]],
     ) -> None:
         self.dependant = dependant
@@ -56,13 +56,14 @@ class Task(Generic[DependencyType]):
     def compute(
         self,
         state: ExecutionState,
-    ) -> Union[
-        Awaitable[Iterable[Optional[ExecutorTask]]], Iterable[Optional[ExecutorTask]]
-    ]:
+    ) -> Union[Awaitable[Iterable[Optional[TaskInfo]]], Iterable[Optional[TaskInfo]]]:
+        raise NotImplementedError
+
+    def as_executor_task(self, state: ExecutionState) -> TaskInfo:
         raise NotImplementedError
 
     def gather_params(
-        self, results: Dict[DependantProtocol[Any], Any]
+        self, results: Dict[DependantBase[Any], Any]
     ) -> Tuple[List[Any], Dict[str, Any]]:
         positional: List[Any] = []
         keyword: Dict[str, Any] = {}
@@ -74,20 +75,14 @@ class Task(Generic[DependencyType]):
                     keyword[dep.parameter.name] = results[dep.dependency.dependant]
         return positional, keyword
 
-    def gather_new_tasks(
-        self, state: ExecutionState
-    ) -> Iterable[Optional[ExecutorTask]]:
+    def gather_new_tasks(self, state: ExecutionState) -> Iterable[Optional[TaskInfo]]:
         """Look amongst our dependants to see if any of them are now dependency free"""
-        new_tasks: Deque[Optional[ExecutorTask]] = deque()
+        new_tasks: Deque[Optional[TaskInfo]] = deque()
         for dependant in state.dependants[self.dependant]:
             count = state.dependency_counts[dependant.dependant]
             if count == 1:
                 # this dependant has no further dependencies, so we can compute it now
-                newtask = functools.partial(
-                    dependant.compute,
-                    state,
-                )
-                new_tasks.append(newtask)  # type: ignore[arg-type] # because of partial
+                new_tasks.append(dependant.as_executor_task(state))
                 # pop it from dependency counts so that we can
                 # tell when we've satisfied all dependencies below
                 state.dependency_counts.pop(dependant.dependant)
@@ -106,17 +101,32 @@ class Task(Generic[DependencyType]):
 
 
 class AsyncTask(Task[DependencyType]):
-    __slots__ = ()
+    __slots__ = ("is_gen", "call")
+
+    def __init__(
+        self,
+        dependant: DependantBase[DependencyType],
+        dependencies: List[DependencyParameter[Task[Any]]],
+    ) -> None:
+        super().__init__(dependant, dependencies)
+        assert self.dependant.call is not None
+        self.call = self.dependant.call
+        self.is_gen = is_async_gen_callable(self.call)
+
+    def as_executor_task(self, state: ExecutionState) -> AsyncTaskInfo:
+        return AsyncTaskInfo(
+            dependant=self.dependant,
+            task=functools.partial(self.compute, state),
+        )
 
     async def compute(
         self,
         state: ExecutionState,
-    ) -> Iterable[Optional[ExecutorTask]]:
+    ) -> Iterable[Optional[TaskInfo]]:
         args, kwargs = self.gather_params(state.results)
 
-        assert self.dependant.call is not None
-        call = self.dependant.call
-        if is_async_gen_callable(call):
+        call = self.call
+        if self.is_gen:
             stack = state.container_state.stacks[self.dependant.scope]
             if not isinstance(stack, AsyncExitStack):
                 raise IncompatibleDependencyError(
@@ -137,18 +147,33 @@ class AsyncTask(Task[DependencyType]):
 
 
 class SyncTask(Task[DependencyType]):
-    __slots__ = ()
+    __slots__ = ("is_gen", "call")
+
+    def __init__(
+        self,
+        dependant: DependantBase[DependencyType],
+        dependencies: List[DependencyParameter[Task[Any]]],
+    ) -> None:
+        super().__init__(dependant, dependencies)
+        assert self.dependant.call is not None
+        self.call = self.dependant.call
+        self.is_gen = is_gen_callable(self.call)
+
+    def as_executor_task(self, state: ExecutionState) -> SyncTaskInfo:
+        return SyncTaskInfo(
+            dependant=self.dependant,
+            task=functools.partial(self.compute, state),
+        )
 
     def compute(
         self,
         state: ExecutionState,
-    ) -> Iterable[Optional[ExecutorTask]]:
+    ) -> Iterable[Optional[TaskInfo]]:
 
         args, kwargs = self.gather_params(state.results)
 
-        assert self.dependant.call is not None
-        call = self.dependant.call
-        if is_gen_callable(self.dependant.call):
+        call = self.call
+        if self.is_gen:
             if TYPE_CHECKING:
                 call = cast(GeneratorProvider[DependencyType], call)
             stack = state.container_state.stacks[self.dependant.scope]
